Changelog of qgispluginreleaser
===================================================


0.1 (2016-01-19)
----------------

- Initial project structure created with nensskel.

- Changing versions in metadata.txt in the prerelease/postrelease step.

- Creating a zipfile (with version number in the filename) automatically in
  the release step. Note that you must answer "yes" to the "checkout a tag?"
  question.
